==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/calendar/api/gwt/endpoint/CalendarsEndpointPromise.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.calendar.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;
import java.util.concurrent.CompletableFuture;

public class CalendarsEndpointPromise implements net.bluemind.calendar.api.ICalendarsPromise {

	private net.bluemind.calendar.api.ICalendarsAsync impl;

	public CalendarsEndpointPromise(net.bluemind.calendar.api.ICalendarsAsync impl) {
		this.impl = impl;
	}

	@Override
	public CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> search(net.bluemind.calendar.api.CalendarsVEventQuery query  ) {
		
		CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> ret = new CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>();
		AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> handler = new AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>() {
			public void success(List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>> value) {
				ret.complete(value);
			}
			
			public void failure(Throwable t) {
				ret.completeExceptionally(t);
			}
		};

		this.impl.search(query,  handler);
		return ret;
	}


	@Override
	public CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> searchPendingCounters(List<String> calendars  ) {
		
		CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> ret = new CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>();
		AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> handler = new AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>() {
			public void success(List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>> value) {
				ret.complete(value);
			}
			
			public void failure(Throwable t) {
				ret.completeExceptionally(t);
			}
		};

		this.impl.searchPendingCounters(calendars,  handler);
		return ret;
	}

}

==> net.bluemind.p2.platform-5.5.3112.zip: net/bluemind/calendar/api/gwt/endpoint/CalendarsEndpointPromise.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.calendar.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;
import java.util.concurrent.CompletableFuture;

public class CalendarsEndpointPromise implements net.bluemind.calendar.api.ICalendarsPromise {

	private net.bluemind.calendar.api.ICalendarsAsync impl;

	public CalendarsEndpointPromise(net.bluemind.calendar.api.ICalendarsAsync impl) {
		this.impl = impl;
	}

	@Override
	public CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> multipleGetByRange(net.bluemind.calendar.api.CalendarsVEventRange range  ) {
		
		CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> ret = new CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>();
		AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> handler = new AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>() {
			public void success(List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>> value) {
				ret.complete(value);
			}
			
			public void failure(Throwable t) {
				ret.completeExceptionally(t);
			}
		};

		this.impl.multipleGetByRange(range,  handler);
		return ret;
	}


	@Override
	public CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> search(net.bluemind.calendar.api.CalendarsVEventQuery query  ) {
		
		CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> ret = new CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>();
		AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> handler = new AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>() {
			public void success(List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>> value) {
				ret.complete(value);
			}
			
			public void failure(Throwable t) {
				ret.completeExceptionally(t);
			}
		};

		this.impl.search(query,  handler);
		return ret;
	}


	@Override
	public CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> searchPendingCounters(List<String> calendars  ) {
		
		CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> ret = new CompletableFuture<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>();
		AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>> handler = new AsyncHandler<List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>>>() {
			public void success(List<net.bluemind.core.container.model.ItemContainerValue<net.bluemind.calendar.api.VEventSeries>> value) {
				ret.complete(value);
			}
			
			public void failure(Throwable t) {
				ret.completeExceptionally(t);
			}
		};

		this.impl.searchPendingCounters(calendars,  handler);
		return ret;
	}

}
